@@ -28,7 +28,7 @@ Usage:
 done
 
 USER_NAME=${USER_NAME:-gbasedbt}
-USER_UPPER=$(echo $USER_NAME|tr [a-z] [A-Z])
+USER_UPPER=$(echo "$USER_NAME"|tr [a-z] [A-Z])
 WORKDIR=$(pwd)
 
 #### do clean
